<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>Cmd</name>
    <message>
        <location filename="../src/cmd.cpp" line="163"/>
        <source>Administrator Access Required</source>
        <translation>Pääkäyttäjän oikeudet vaaditaan</translation>
    </message>
    <message>
        <location filename="../src/cmd.cpp" line="164"/>
        <source>This operation requires administrator privileges. Please restart the application and enter your password when prompted.</source>
        <translation>Toiminto vaatii järjestelmänvalvojan oikeudet. Käynnistä sovellus uudelleen ja anna salasanasi pyydettäessä.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="57"/>
        <location filename="../src/mainwindow.ui" line="198"/>
        <source>Please select the location of your installation:</source>
        <translation>Valitse asennuspaikkasi:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="71"/>
        <location filename="../src/mainwindow.ui" line="211"/>
        <source>Select drive:</source>
        <translation>Valitse asema:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="78"/>
        <location filename="../src/mainwindow.ui" line="228"/>
        <source>Select partition:</source>
        <translation>Valitse osio:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="249"/>
        <source>Frugal mode:</source>
        <translation>Säästävä tila:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="296"/>
        <source>Boot options:</source>
        <translation>Käynnistyksen valinnat:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="129"/>
        <location filename="../src/mainwindow.ui" line="313"/>
        <source>UEFI entry name:</source>
        <translation>UEFI-nimi:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="20"/>
        <source>UEFI manager</source>
        <translation>UEFI manageri</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="41"/>
        <source>EFI stub installer</source>
        <translation>EFI stub asentaja</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="47"/>
        <source>This options copies the kernel and initrd files to ESP (EFI System Partition) and creates an UEFI entry that allows to boot the installation directly, bypassing GRUB and other bootloaders. To boot using the created UEFI entry, access the UEFI boot selection menu at startup by pressing the appropriate key for your device (e.g., F12, F9, or Esc, depending on the manufacturer).</source>
        <translation>Tämä vaihtoehto kopioi ytimen ja initrd-tiedostot ESP:hen (EFI System Partition) ja luo UEFI-merkinnän, jonka avulla asennus voidaan käynnistää suoraan ohittaen GRUB:n ja muut käynnistyslataimet. Jos haluat käynnistää luodun UEFI-merkinnän avulla, siirry UEFI-käynnistysvalintavalikkoon käynnistyksen yhteydessä painamalla laitteellesi sopivaa näppäintä (esim. F12, F9 tai Esc, valmistajasta riippuen).</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="115"/>
        <source>Kernel to boot:</source>
        <translation>Kernel käynnistykseen:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="122"/>
        <source>Kernel options:</source>
        <translation>Kernel valinnat:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="393"/>
        <source>About this application</source>
        <translation>Tietoja sovelluksesta</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="396"/>
        <source>About...</source>
        <translation>Tietoja...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="402"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="418"/>
        <source>Quit application</source>
        <translation>Lopeta sovellus</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="421"/>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="427"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="443"/>
        <source>Display help </source>
        <translation>Näytä ohje</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="36"/>
        <source>Manage UEFI entries</source>
        <translation>Hallitse UEFI kohteita</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="166"/>
        <source>Frugal EFI stub installer</source>
        <translation>Frugal EFI stub asentaja</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="172"/>
        <source>This option is meant to create a bootable entry for MX and antiX frugal installation, it creates an EFI boot entry for launching the installation directly, bypassing GRUB and other bootloaders. To boot using the created UEFI entry, access the UEFI boot selection menu at startup by pressing the appropriate key for your device (e.g., F12, F9, or Esc, depending on the manufacturer).</source>
        <translation>Asetuksen tarkoituksena on luoda käynnistyskohta MX ja Anti-X &quot;frugal&quot; asennukselle. Se luo käynnistyskohdan suoraan EFI:lle, ohittaen GRUB ja muut käynnistyslataimet. Jos haluat käynnistää UEFI:n avulla, avaa käynnistysvalikko käynnistyksen yhteydessä painamalla tietokoneellesi sopivaa näppäintä (esim. F12, F9 tai ESC valmistajasta riippuen).</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="446"/>
        <source>Help</source>
        <translation>Ohje</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="452"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="465"/>
        <location filename="../src/mainwindow.cpp" line="885"/>
        <location filename="../src/mainwindow.cpp" line="1677"/>
        <source>Next</source>
        <translation>Seuraava</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="503"/>
        <source>Back</source>
        <translation>Takaisin</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="718"/>
        <location filename="../src/mainwindow.cpp" line="908"/>
        <location filename="../src/mainwindow.cpp" line="1487"/>
        <location filename="../src/mainwindow.cpp" line="1497"/>
        <source>UEFI Installer</source>
        <translation>UEFI asentaja</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="719"/>
        <source>A recent frugal install has been detected. Do you wish to add a UEFI entry direct to your UEFI system menu?</source>
        <translation>Viimeinen frugal asennus on havaittu. Haluatko lisätä UEFI-kohteen suoraan UEFI-valikkoon?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="956"/>
        <source>Could not retrieve UUID for %1</source>
        <translation>Ei voi hakea UUID:tä kohteelle %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="963"/>
        <source>Enter passphrase to unlock %1 encrypted partition:</source>
        <translation>Avaa salatun osion %1 lukitus antamalla sen salasana:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="968"/>
        <source>Passphrase entry cancelled or empty for %1</source>
        <translation>Salasanan merkintä peruutettu tai tyhjä kohteelle %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="974"/>
        <source>Could not open %1 LUKS container</source>
        <translation>Ei voi avata %1 LUKS-säilöstä</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1488"/>
        <source>Are you sure this is the MX or antiX Frugal installation location?
Missing mandatory files in directory: </source>
        <translation>Oletko varma, että tämä on MX ​​tai antiX Frugal asennuskohde?Hakemistosta puuttuu pakollisia tiedostoja:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1561"/>
        <source>Not enough space on the EFI System Partition to copy the kernel and initrd files.</source>
        <translation>EFI-osiossa ei ole riittävästi tilaa kernelin ja initrd-tiedostojen kopioimiseen.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1614"/>
        <source>All fields are required</source>
        <translation>Kaikki kentät ovat pakollisia</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1637"/>
        <source>Could not select ESP</source>
        <translation>ESP:n valinta ei onnistunut</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1655"/>
        <source>About %1</source>
        <translation>%1 lisätietoja</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="130"/>
        <source>Select EFI file</source>
        <translation>Valitse EFI-tiedosto</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="130"/>
        <source>EFI files (*.efi *.EFI)</source>
        <translation>EFI tiedostot (*.efi *.EFI)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="141"/>
        <location filename="../src/mainwindow.cpp" line="155"/>
        <location filename="../src/mainwindow.cpp" line="956"/>
        <location filename="../src/mainwindow.cpp" line="968"/>
        <location filename="../src/mainwindow.cpp" line="974"/>
        <location filename="../src/mainwindow.cpp" line="1697"/>
        <location filename="../src/mainwindow.cpp" line="1821"/>
        <location filename="../src/mainwindow.cpp" line="1873"/>
        <location filename="../src/mainwindow.cpp" line="1884"/>
        <location filename="../src/mainwindow.cpp" line="1891"/>
        <location filename="../src/mainwindow.cpp" line="1902"/>
        <location filename="../src/mainwindow.cpp" line="1912"/>
        <location filename="../src/mainwindow.cpp" line="1927"/>
        <location filename="../src/mainwindow.cpp" line="1932"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="141"/>
        <source>Could not find the source mountpoint for %1</source>
        <translation>Ei löytynyt lähteen liitospistettä %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="145"/>
        <source>Set name</source>
        <translation>Aseta nimi</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="145"/>
        <source>Enter the name for the UEFI menu item:</source>
        <translation>Anna valikolle UEFI nimi:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="155"/>
        <source>Something went wrong, could not add entry.</source>
        <translation>Jotain meni väärin, merkintää ei voitu lisätä.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="745"/>
        <location filename="../src/mainwindow.cpp" line="787"/>
        <location filename="../src/mainwindow.cpp" line="1709"/>
        <source>Timeout: %1 seconds</source>
        <translation>Aikakatkaisu: %1 sekuntia</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="747"/>
        <location filename="../src/mainwindow.cpp" line="786"/>
        <location filename="../src/mainwindow.cpp" line="803"/>
        <location filename="../src/mainwindow.cpp" line="1726"/>
        <source>Boot Next: %1</source>
        <translation>Seuraava käynnistys: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="749"/>
        <source>Boot Current: %1</source>
        <translation>Käynnistys viimeisin: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="762"/>
        <source>You can use the Up/Down buttons, or drag &amp; drop items to change boot order.
- Items are listed in the boot order.
- Grayed out lines are inactive.</source>
        <translation>Muuta käynnistysjärjestystä nuolinäppäimillä tai vedä ja pudota kohteet.
- Kohteet luetellaan käynnistysjärjestyksessä.
- Harmaat rivit eivät ole aktiivisia.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="773"/>
        <location filename="../src/mainwindow.cpp" line="838"/>
        <source>Set ac&amp;tive</source>
        <translation>Aseta ak&amp;tiiviseksi</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="774"/>
        <source>&amp;Add entry</source>
        <translation>&amp;Lisää merkintä</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="775"/>
        <source>Boot &amp;next</source>
        <translation>Käynnistä &amp;seuraava</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="776"/>
        <source>Move &amp;down</source>
        <translation>Siirrä &amp;alas</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="777"/>
        <source>&amp;Remove entry</source>
        <translation>&amp;Poista merkintä</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="779"/>
        <source>Re&amp;set next</source>
        <translation>Re&amp;setoi seuraava</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="780"/>
        <source>Change &amp;timeout</source>
        <translation>Muuta &amp;aikakatkaisu</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="781"/>
        <source>Move &amp;up</source>
        <translation>Siirrä &amp;ylös</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="786"/>
        <location filename="../src/mainwindow.cpp" line="803"/>
        <source>not set, will boot using list order</source>
        <translation>ei asetettu, käynnistyy listan mukaan</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="835"/>
        <source>Set &amp;inactive</source>
        <translation>Aseta &amp;passiiviseksi</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="908"/>
        <source>Failed to open grub.entry file.</source>
        <translation>Tiedoston grub.entry avaaminen epäonnistui.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1658"/>
        <source>Tool for managing UEFI boot entries</source>
        <translation>Työkalu UEFI-käynnistyksen hallintaan</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1821"/>
        <source>Both old and new EFI labels must be specified</source>
        <translation>Sekä vanhat että uudet EFI-nimet on määritettävä</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1874"/>
        <source>Multiple boot entries found for label &apos;%1&apos;: %2 and %3;</source>
        <translation>Useita käynnistyskohteita nimelle &quot;%1&quot;: %2 ja %3;</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1884"/>
        <source>No EFI data found for label &apos;%1&apos;.</source>
        <translation>EFI-dataa ei löytynyt nimelle &quot;%1&quot;.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1892"/>
        <source>EFI label &apos;%1&apos; is linked to an unknown partition &apos;%2&apos;.</source>
        <translation>EFI-nimi &quot;%1&quot; on linkitetty tuntemattomaan osioon &quot;%2&quot;.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1903"/>
        <source>Unexpected device name format &apos;%1&apos; for partition related to the label.</source>
        <translation>Odottamaton laittenimi &quot;%1&quot; osiolle liittyvälle nimelle.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1913"/>
        <source>Device partition number [%1] differs from EFI entry partition number [%2].</source>
        <translation>Laiteosion numero [%1] eroaa EFI-kohteen osion numerosta [%2].</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1927"/>
        <source>Failed to delete old boot entry</source>
        <translation>Vanhan käynnistysmerkinnän poistaminen epäonnistui</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1932"/>
        <source>Failed to create new boot entry</source>
        <translation>Uuden käynnistysmerkinnän luominen epäonnistui</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1497"/>
        <source>Failed to read grub.entry file.</source>
        <translation>Tiedoston grub.entry lukeminen epäonnistui.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="893"/>
        <location filename="../src/mainwindow.cpp" line="1510"/>
        <source>Install</source>
        <translation>Asenna</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1516"/>
        <source>Select Frugal Directory</source>
        <translation>Valitse Frugal hakemisto</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1523"/>
        <source>No EFI System Partitions found.</source>
        <translation>EFI-osioita ei löytynyt.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1529"/>
        <source>Select EFI System Partition</source>
        <translation>Valitse EFI-osio</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1530"/>
        <source>EFI System Partitions:</source>
        <translation>EFI-osiot:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1543"/>
        <source>No EFI System Partition selected</source>
        <translation>EFI-osioita ei valittuna.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1550"/>
        <source>Could not mount selected EFI System Partition</source>
        <translation>Valittua EFI-osiota ei voitu liittää</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1577"/>
        <location filename="../src/mainwindow.cpp" line="1621"/>
        <source>Could not mount partition. Please make sure you selected the correct partition.</source>
        <translation>Osiota ei voitu liittää. Varmista, että valitsit oikean osion.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1586"/>
        <source>No directory selected</source>
        <translation>Hakemistoa ei ole valittuna</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1606"/>
        <location filename="../src/mainwindow.cpp" line="1643"/>
        <source>EFI stub installed successfully.</source>
        <translation>EFI stub asennettu onnistuneesti.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1608"/>
        <location filename="../src/mainwindow.cpp" line="1645"/>
        <source>Failed to install EFI stub.</source>
        <translation>EFI stub asentaminen epäonnistui.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1656"/>
        <source>Version: </source>
        <translation>Versio: </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1660"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1661"/>
        <source>%1 License</source>
        <translation>%1 lisenssi</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1669"/>
        <source>%1 Help</source>
        <translation>%1 ohje</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1697"/>
        <source>Something went wrong, could not save boot order.</source>
        <translation>Jotain meni väärin, käynnistysjärjestystä ei voitu tallentaa.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1705"/>
        <source>Set timeout</source>
        <translation>Aseta aikakatkaisu</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1705"/>
        <source>Timeout in seconds:</source>
        <translation>Aikakatkaisu sekunneissa:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1744"/>
        <source>Removal confirmation</source>
        <translation>Poiston vahvistus</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1745"/>
        <source>Are you sure you want to delete this boot entry?
%1</source>
        <translation>Haluatko poistaa tämän käynnistyksen?
%1</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/about.cpp" line="99"/>
        <source>License</source>
        <translation>Lisenssi</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="100"/>
        <source>Changelog</source>
        <translation>Muutosloki</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="101"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="125"/>
        <source>Error: Changelog file is missing.</source>
        <translation>Virhe: Muutosloki puuttuu.</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="127"/>
        <source>Error: Required utility &apos;zless&apos; is missing.</source>
        <translation>Virhe: Pakollinen apuohjelma &quot;zless&quot; puuttuu.</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="134"/>
        <source>&amp;Close</source>
        <translation>&amp;Sulje</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="85"/>
        <source>uefi-manager is a tool for managing UEFI boot entries</source>
        <translation>uefi-manager on UEFI-käynnistyksen hallintatyökalu</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="88"/>
        <source>Perform EFI Stub installation for frugal installation.</source>
        <translation>Suorita EFI Stub asennus frugal asennuksella.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="66"/>
        <location filename="../src/main.cpp" line="95"/>
        <source>UEFI Manager</source>
        <translation>UEFI Hallinta</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="89"/>
        <source>Run in test mode (bypass UEFI detection for GUI testing).</source>
        <translation>Suorita testitilassa (ohittaa UEFI-tunnistuksen graafisen käyttöliittymän).</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="96"/>
        <source>This system doesn&apos;t seem to support UEFI, or was not booted in UEFI mode. Exiting.</source>
        <translation>Tämä tietokone ei tue UEFI menetelmää tai se ei ole UEFI-tilassa. Poistutaan.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="107"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="108"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Olet kirjautunut pääkäyttäjänä. Kirjaudu sisään tavallisena käyttäjänä käyttääksesi tätä ohjelmaa.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="113"/>
        <source>version:</source>
        <translation>versio:</translation>
    </message>
</context>
</TS>